Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(702)

Unified Diff: util/mac/process_reader.cc

Issue 656703002: Convert NULL to nullptr (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Fix 80-column violations Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « util/mac/mach_o_image_symbol_table_reader.cc ('k') | util/mac/process_reader_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: util/mac/process_reader.cc
diff --git a/util/mac/process_reader.cc b/util/mac/process_reader.cc
index e0f322d24aaa6f85a9b8b6a5f236a5a2480b93ae..c142080b6bd32f741981fa379096de3a6788625b 100644
--- a/util/mac/process_reader.cc
+++ b/util/mac/process_reader.cc
@@ -83,7 +83,7 @@ ProcessReader::Thread::Thread()
priority(0) {
}
-ProcessReader::Module::Module() : name(), reader(NULL), timestamp(0) {
+ProcessReader::Module::Module() : name(), reader(nullptr), timestamp(0) {
}
ProcessReader::Module::~Module() {
@@ -121,7 +121,7 @@ bool ProcessReader::Initialize(task_t task) {
int mib[] = {CTL_KERN, KERN_PROC, KERN_PROC_PID, pid};
size_t len = sizeof(kern_proc_info_);
- if (sysctl(mib, arraysize(mib), &kern_proc_info_, &len, NULL, 0) != 0) {
+ if (sysctl(mib, arraysize(mib), &kern_proc_info_, &len, nullptr, 0) != 0) {
PLOG(ERROR) << "sysctl for pid " << pid;
return false;
}
@@ -395,8 +395,8 @@ void ProcessReader::InitializeModules() {
// Note that all_image_infos.infoArrayCount may be 0 if a crash occurred while
// dyld was loading the executable. This can happen if a required dynamic
// library was not found. Similarly, all_image_infos.infoArray may be NULL if
// a crash occurred while dyld was updating it.
//
// TODO(mark): It may be possible to recover from these situations by looking
// through memory mappings for Mach-O images.
@@ -405,7 +405,7 @@ void ProcessReader::InitializeModules() {
return;
}
if (!all_image_infos.infoArray) {
- LOG(WARNING) << "all_image_infos.infoArray is NULL";
+ LOG(WARNING) << "all_image_infos.infoArray is nullptr";
return;
}
« no previous file with comments | « util/mac/mach_o_image_symbol_table_reader.cc ('k') | util/mac/process_reader_test.cc » ('j') | no next file with comments »
@@ -395,8 +395,8 @@ void ProcessReader::InitializeModules() {
// Note that all_image_infos.infoArrayCount may be 0 if a crash occurred while
// dyld was loading the executable. This can happen if a required dynamic
- // library was not found. Similarly, all_image_infos.infoArray may be NULL if
- // a crash occurred while dyld was updating it.
+ // library was not found. Similarly, all_image_infos.infoArray may be nullptr
+ // if a crash occurred while dyld was updating it.
//
// TODO(mark): It may be possible to recover from these situations by looking

Powered by Google App Engine
This is Rietveld 408576698